@@ -34,7 +34,7 @@ console = logging.StreamHandler()
 formatter = logging.Formatter('[distfit] >%(levelname)s> %(message)s')
 console.setFormatter(formatter)
 logger.addHandler(console)
-logger = logging.getLogger(__name__)
+logger = logging.getLogger()
 
 
 # %% Class dist
@@ -612,10 +612,12 @@ class distfit():
              chart='PDF',
              n_top=1,
              title='',
-             emp_properties={'color': '#000000', 'linewidth': 1.3, 'linestyle': '-'},
-             pdf_properties={'color': '#004481', 'linewidth': 2, 'linestyle': '-'},
-             bar_properties={'color': '#ffffff', 'linewidth': 1, 'edgecolor': '#808080', 'align': 'center'},
-             cii_properties={'color': '#880808', 'linewidth': 2, 'linestyle': 'dashed', 'marker': 'x', 'size': 20, 'color_sign_multipletest': 'g', 'color_sign': 'g', 'color_general': 'r'},
+             emp_properties={'color': '#000000', 'linewidth': 3, 'linestyle': '-'},
+             pdf_properties={'color': '#880808', 'linewidth': 3, 'linestyle': '-'},
+             bar_properties={'color': '#607B8B', 'linewidth': 1, 'edgecolor': '#5A5A5A', 'align': 'center'},
+             cii_properties={'color': '#C41E3A', 'linewidth': 3, 'linestyle': 'dashed', 'marker': 'x', 'size': 20, 'color_sign_multipletest': 'g', 'color_sign': 'g', 'color_general': 'r'},
+             xlabel='Values',
+             ylabel='Frequency',
              figsize=(20, 15),
              xlim=None,
              ylim=None,
@@ -639,19 +641,23 @@ class distfit():
         emp_properties : dict
             The line properties of the emperical line.
                 * None: Do not plot.
-                * {'color': '#000000', 'linewidth': 1.3, 'linestyle': '-'}: default
+                * {'color': '#000000', 'linewidth': 3, 'linestyle': '-'}
         pdf_properties : dict
             The line properties of the PDF or the CDF.
                 * None: Do not plot.
-                * {'color': '#004481', 'linewidth': 2, 'linestyle': '-'}: default
+                * {'color': '#880808', 'linewidth': 3, 'linestyle': '-'}
         bar_properties : dict
             bar properties of the histogram.
                 * None: Do not plot.
-                * {'color': '#ffffff', 'linewidth': 1, 'edgecolor': '#808080', 'align': 'edge'}: default
+                * {'color': '#607B8B', 'linewidth': 1, 'edgecolor': '#5A5A5A', 'align': 'edge'}
         cii_properties : dict
             bar properties of the histogram.
                 * None: Do not plot.
-                * {'color': '#880808', 'linewidth': 2, 'linestyle': 'dashed', 'marker': 'x', 'size': 20, 'color_sign_multipletest': 'g', 'color_sign': 'g', 'color_general': 'r'}: default
+                * {'color': '#C41E3A', 'linewidth': 3, 'linestyle': 'dashed', 'marker': 'x', 'size': 20, 'color_sign_multipletest': 'g', 'color_sign': 'g', 'color_general': 'r'}
+        xlabel : String, (default: 'value')
+            Label for the x-axis.
+        ylabel : String, (default: 'Frequency')
+            Label for the y-axis.
         figsize : tuple, optional (default: (10,8))
             The figure size.
         xlim : Float, optional (default: None)
@@ -713,20 +719,20 @@ class distfit():
         """
         if verbose is not None: set_logger(verbose)
         if not hasattr(self, 'model'): raise Exception('[distfit] Error in plot: For plotting, A model is required. Try fitting first on your data using fit_transform(X)')
-        if cii_properties is not None: cii_properties = {**{'color': '#880808', 'linewidth': 2, 'linestyle': 'dashed', 'marker': 'x', 'size': 20, 'color_sign_multipletest': 'g', 'color_sign': 'g', 'color_general': 'r', 'alpha': 1}, **cii_properties}
-        if emp_properties is not None: emp_properties = {**{'color': '#000000', 'linewidth': 1.3, 'linestyle': '-', 'label': None}, **emp_properties}
-        if pdf_properties is not None: pdf_properties = {**{'color': '#004481', 'linewidth': 2, 'linestyle': '-'}, **pdf_properties}
-        if bar_properties is not None: bar_properties = {**{'color': '#ffffff', 'linewidth': 1, 'edgecolor': '#808080', 'align': 'edge'}, **bar_properties}
+        if cii_properties is not None: cii_properties = {**{'color': '#C41E3A', 'linewidth': 3, 'linestyle': 'dashed', 'marker': 'x', 'size': 20, 'color_sign_multipletest': 'g', 'color_sign': 'g', 'color_general': 'r', 'alpha': 1}, **cii_properties}
+        if emp_properties is not None: emp_properties = {**{'color': '#000000', 'linewidth': 3, 'linestyle': '-', 'label': None}, **emp_properties}
+        if pdf_properties is not None: pdf_properties = {**{'color': '#880808', 'linewidth': 3, 'linestyle': '-'}, **pdf_properties}
+        if bar_properties is not None: bar_properties = {**{'color': '#607B8B', 'linewidth': 1, 'edgecolor': '#5A5A5A', 'align': 'center'}, **bar_properties}
 
         logger.info('Create %s plot for the %s method.' %(chart, self.method))
         if chart.upper()=='PDF' and self.method=='parametric':
-            fig, ax = _plot_parametric(self, title=title, figsize=figsize, xlim=xlim, ylim=ylim, fig=fig, ax=ax, grid=grid, emp_properties=emp_properties, pdf_properties=pdf_properties, bar_properties=bar_properties, cii_properties=cii_properties, n_top=n_top, cmap=cmap)
+            fig, ax = _plot_parametric(self, title=title, figsize=figsize, xlim=xlim, ylim=ylim, fig=fig, ax=ax, grid=grid, emp_properties=emp_properties, pdf_properties=pdf_properties, bar_properties=bar_properties, cii_properties=cii_properties, n_top=n_top, cmap=cmap, xlabel=xlabel, ylabel=ylabel)
         elif chart.upper()=='PDF' and self.method=='discrete':
-            fig, ax = plot_binom(self, title=title, figsize=figsize, xlim=xlim, ylim=ylim, grid=grid, emp_properties=emp_properties, pdf_properties=pdf_properties, bar_properties=bar_properties, cii_properties=cii_properties)
+            fig, ax = plot_binom(self, title=title, figsize=figsize, xlim=xlim, ylim=ylim, grid=grid, emp_properties=emp_properties, pdf_properties=pdf_properties, bar_properties=bar_properties, cii_properties=cii_properties, xlabel=xlabel, ylabel=ylabel)
         elif chart.upper()=='PDF' and (self.method=='quantile') or (self.method=='percentile'):
-            fig, ax = _plot_quantile(self, title=title, figsize=figsize, xlim=xlim, ylim=ylim, fig=fig, ax=ax, grid=grid, emp_properties=emp_properties, bar_properties=bar_properties, cii_properties=cii_properties)
+            fig, ax = _plot_quantile(self, title=title, figsize=figsize, xlim=xlim, ylim=ylim, fig=fig, ax=ax, grid=grid, emp_properties=emp_properties, bar_properties=bar_properties, cii_properties=cii_properties, xlabel=xlabel, ylabel=ylabel)
         elif chart.upper()=='CDF' and (self.method=='parametric' or self.method=='discrete'):
-            fig, ax = self.plot_cdf(n_top=n_top, title=title, figsize=figsize, xlim=xlim, ylim=ylim, fig=fig, ax=ax, grid=grid, emp_properties=emp_properties, cdf_properties=pdf_properties, cii_properties=cii_properties, cmap=cmap)
+            fig, ax = self.plot_cdf(n_top=n_top, title=title, figsize=figsize, xlim=xlim, ylim=ylim, fig=fig, ax=ax, grid=grid, emp_properties=emp_properties, cdf_properties=pdf_properties, cii_properties=cii_properties, cmap=cmap, xlabel=xlabel, ylabel=ylabel)
         else:
             logger.warning('Nothing to plot. %s not yet implemented or possible for the %s approach.' %(chart, self.method))
             fig, ax = None, None
@@ -853,6 +859,8 @@ class distfit():
                  n_top=1,
                  title='',
                  figsize=(20, 15),
+                 xlabel='Values',
+                 ylabel='Frequency',
                  xlim=None,
                  ylim=None,
                  fig=None,
@@ -871,6 +879,10 @@ class distfit():
             Show the top number of results. The default is 1.
         title : String, optional (default: '')
             Title of the plot.
+        xlabel : string (default: 'Values')
+            Label of the x-axis.
+        ylabel : string (default: 'Frequencies')
+            Label of the y-axis.
         figsize : tuple, optional (default: (10,8))
             The figure size.
         xlim : Float, optional (default: None)
@@ -964,15 +976,15 @@ class distfit():
                 # Plot the best CDF
                 ax.plot(x, cdf(x), **cdf_properties)
 
-            # Plot other CDFs
-            if n_top>1:
-                n_top = np.minimum(self.summary.shape[0], n_top + 1)
-                if cmap is not None: self.summary['color'] = colourmap.generate(self.summary.shape[0], cmap=cmap, scheme='hex')
-                for i in range(1, n_top):
-                    # Plot cdf
-                    cdf = self.summary['model'].iloc[i].cdf
-                    # Plot CDF for linearly scale samples between min-max range(x)
-                    ax.plot(x, cdf(x), **{'label': self.summary['distr'].iloc[i], 'linewidth': 1.5, 'linestyle': '--', 'color': self.summary['color'].iloc[i]})
+                # Plot other CDFs
+                if n_top>1:
+                    n_top = np.minimum(self.summary.shape[0], n_top + 1)
+                    if cmap is not None: self.summary['color'] = colourmap.generate(self.summary.shape[0], cmap=cmap, scheme='hex')
+                    for i in range(1, n_top):
+                        # Plot cdf
+                        cdf = self.summary['model'].iloc[i].cdf
+                        # Plot CDF for linearly scale samples between min-max range(x)
+                        ax.plot(x, cdf(x), **{'label': self.summary['distr'].iloc[i], 'linewidth': 1.5, 'linestyle': '--', 'color': self.summary['color'].iloc[i]})
 
             # plot CII
             results = self.results if hasattr(self, 'results') else None
@@ -986,8 +998,8 @@ class distfit():
 
             # Make text for plot
             ax.set_title(self._make_title(title))
-            ax.set_xlabel('Values')
-            ax.set_ylabel('Frequency')
+            ax.set_xlabel(xlabel)
+            ax.set_ylabel(ylabel)
             ax.legend(loc='upper right')
             ax.grid(grid)
         else:
@@ -1345,9 +1357,9 @@ def _predict_percentile(self, y):
 
 
 # %% Plot bar
-def _plot_pdf_more(df, x, n_top, ax, cmap='Set1'):
+def _plot_pdf_more(df, x, n_top, cmap, pdf_properties, ax):
     if n_top is None: n_top = 1
-    if n_top>1:
+    if n_top>1 and (pdf_properties is not None):
         n_top = np.minimum(df.shape[0], n_top + 1)
         if cmap is not None: df['color'] = colourmap.generate(df.shape[0], cmap=cmap, scheme='hex')
         for i in range(1, n_top):
@@ -1446,7 +1458,7 @@ def _plot_cii_parametric(model, alpha, results, cii_properties, ax):
             ax.scatter(results['y'][idxOUT], np.zeros(len(idxOUT)), s=50, marker=cii_properties_custom['marker'], color=cii_properties_custom['color_general'], **cii_properties)
 
 # %% Plot
-def _plot_quantile(self, title='', figsize=(15, 8), xlim=None, ylim=None, fig=None, ax=None, grid=True, emp_properties={}, bar_properties={}, cii_properties={}):
+def _plot_quantile(self, title='', xlabel='Values', ylabel='Frequency', figsize=(15, 8), xlim=None, ylim=None, fig=None, ax=None, grid=True, emp_properties={}, bar_properties={}, cii_properties={}):
     if ax is None: fig, ax = plt.subplots(figsize=figsize)
     if not hasattr(self, 'results'): self.results=None
 
@@ -1464,8 +1476,8 @@ def _plot_quantile(self, title='', figsize=(15, 8), xlim=None, ylim=None, fig=No
         ax.set_ylim(ylim[0], ylim[1])
 
     ax.grid(grid)
-    ax.set_xlabel('Values')
-    ax.set_ylabel('Frequency')
+    ax.set_xlabel(xlabel)
+    ax.set_ylabel(ylabel)
     ax.set_title(title)
     ax.legend(loc='upper right')
 
@@ -1477,6 +1489,8 @@ def _plot_parametric(self,
                      n_top=1,
                      title='',
                      figsize=(10, 8),
+                     xlabel='Values',
+                     ylabel='Frequency',
                      xlim=None,
                      ylim=None,
                      grid=True,
@@ -1523,7 +1537,7 @@ def _plot_parametric(self,
     # Plot pdf
     _plot_pdf(x, y, best_fit_name + ' (best fit)', pdf_properties, ax)
     # Plot top n pdf
-    _plot_pdf_more(self.summary, x, Param['n_top'], ax, cmap=cmap)
+    _plot_pdf_more(self.summary, x, Param['n_top'], cmap, pdf_properties, ax)
     # plot CII
     results = self.results if hasattr(self, 'results') else None
     _plot_cii_parametric(self.model, self.alpha, results, cii_properties, ax)
@@ -1535,8 +1549,8 @@ def _plot_parametric(self,
         ax.set_ylim(Param['ylim'][0], Param['ylim'][1])
 
     ax.set_title(self._make_title(title))
-    ax.set_xlabel('Values')
-    ax.set_ylabel('Frequency')
+    ax.set_xlabel(xlabel)
+    ax.set_ylabel(ylabel)
     ax.legend(loc='upper right')
     ax.grid(grid)
 
@@ -1949,7 +1963,6 @@ def fit_transform_binom(X, f=1.5, weighted=True, stats='RSS'):
     df['loc'] = model['n']
     df['scale'] = model['p']
     df['arg'] = None
-    
     return df, model, figdata
 
 
@@ -1958,6 +1971,8 @@ def plot_binom(self,
                pdf_properties={},
                bar_properties={},
                cii_properties={},
+               xlabel='Values',
+               ylabel='Frequency',
                title='',
                figsize=(10, 8),
                xlim=None,
@@ -2044,8 +2059,8 @@ def plot_binom(self,
         ax[0].set_xlim(xmin=Param['xlim'][0], xmax=Param['xlim'][1])
     if Param['ylim'] is not None:
         ax[0].set_ylim(ymin=Param['ylim'][0], ymax=Param['ylim'][1])
-    ax[0].set_xlabel('k')
-    ax[0].set_ylabel('Counts')
+    ax[0].set_xlabel(xlabel)
+    ax[0].set_ylabel(ylabel)
     ax[0].legend(loc='upper right')
     ax[0].grid(grid)
     param_str = ', '.join(['{}={:g}'.format(k, v) for k, v in zip(['n', 'p'], best_fit_param)])
