@@ -6,6 +6,24 @@ import distfit
 # print(distfit.__version__)
 # print(dir(distfit))
 
+# %% CDF plot
+from distfit import distfit
+dfit = distfit(verbose=20)
+
+# Random Exponential data
+# X = np.random.exponential(0.5, 10000)
+# X = np.random.uniform(0, 1000, 10000)
+X = np.random.normal(0, 1, 1000)
+dfit = distfit(distr='popular')
+# Fit and plot
+dfit.fit_transform(X)
+# dfit.plot_cdf(n_top=10);
+fig, ax = dfit.plot(chart='PDF', n_top=5, cmap='Set2');
+dfit.plot(chart='CDF', n_top=10, cmap='Set2', ax=ax);
+# dfit.plot_cdf()
+dfit.plot_summary(n_top=10);
+
+
 # %%
 from distfit import distfit
 # Set parameters for the test-case
@@ -24,7 +42,9 @@ y = [0, 1, 10, 11, 12]
 
 results = dfit.predict(y)
 dfit.plot(chart='PDF')
-dfit.plot(chart='CDF')
+dfit.plot(chart='PDF', pdf_properties=None)
+dfit.plot(chart='CDF', n_top=5)
+dfit.plot(chart='CDF', pdf_properties=None, n_top=2)
 dfit.plot_cdf()
 
 # %%
@@ -52,6 +72,13 @@ dfit.fit_transform(X)
 dfit.qqplot(X)
 dfit.qqplot(X, n_top=11, cmap='Set1')
 
+dfit.plot(chart='PDF')
+dfit.plot(chart='PDF', pdf_properties=None)
+dfit.plot(chart='PDF', pdf_properties=None, n_top=10)
+dfit.plot(chart='CDF', n_top=10)
+dfit.plot(chart='CDF', pdf_properties=None, n_top=10)
+
+
 # fig, ax = dfit.plot(chart='CDF', n_top=10);
 # dfit.plot(chart='PDF', n_top=10, fig=fig, ax=ax);
 # dfit.qqplot(X, n_top=10, fig=fig, ax=ax);
